@@ -75,7 +75,7 @@ dnf install -y https://rpms.remirepo.net/enterprise/remi-release-9.rpm
 dnf install -y httpd mod_ssl wget procps
 openssl req -newkey rsa:2048 -nodes -keyout /etc/pki/tls/private/localhost.key -x509 -days 3650 -subj "/CN=localhost" -out /etc/pki/tls/certs/localhost.crt
 dnf module enable php:remi-8.2 -y
-dnf install -y php php-fpm php-mysqlnd php-xml php-pecl-zip php-sodium php-soap php-pecl-xmlrpc \
+dnf install -y php php-fpm php-mysqlnd php-pgsql php-xml php-pecl-zip php-sodium php-soap php-pecl-xmlrpc \
 php-pecl-redis5 php-pecl-memcached php-pecl-memcache php-pecl-ip2location php-pecl-imagick php-pecl-geoip \
 php-mysqlnd php-mbstring php-intl php-gd libzip php-cli php-pecl-pam
 
@@ -115,6 +115,42 @@ mkdir -p /root/whp
 rsync -auzvp --exclude='web-files/' ./ /root/whp/
 echo "✓ Release files copied to /root/whp/"
 
+# Install pgAdmin 4
+echo "Installing pgAdmin 4..."
+dnf install -y https://ftp.postgresql.org/pub/pgadmin/pgadmin4/yum/pgadmin4-redhat-repo-2-1.noarch.rpm
+dnf install -y pgadmin4-web
+
+# Configure pgAdmin 4
+echo "Configuring pgAdmin 4..."
+# Create config_local.py for pgAdmin
+cat > /usr/pgadmin4/web/config_local.py << 'EOF'
+import os
+LOG_FILE = '/var/log/pgadmin/pgadmin4.log'
+SQLITE_PATH = '/var/lib/pgadmin/pgadmin4.db'
+SESSION_DB_PATH = '/var/lib/pgadmin/sessions'
+STORAGE_DIR = '/var/lib/pgadmin/storage'
+SERVER_MODE = True
+EOF
+
+# Set up pgAdmin directories
+mkdir -p /var/lib/pgadmin
+mkdir -p /var/log/pgadmin
+chown -R apache:apache /var/lib/pgadmin
+chown -R apache:apache /var/log/pgadmin
+
+# Configure Apache for pgAdmin
+cat > /etc/httpd/conf.d/pgadmin4.conf << 'EOF'
+LoadModule wsgi_module modules/mod_wsgi_python3.so
+WSGIDaemonProcess pgadmin processes=1 threads=25 python-home=/usr/pgadmin4/venv
+WSGIScriptAlias /pgadmin4 /usr/pgadmin4/web/pgAdmin4.wsgi
+
+<Directory /usr/pgadmin4/web/>
+    WSGIProcessGroup pgadmin
+    WSGIApplicationGroup %{GLOBAL}
+    Require all granted
+</Directory>
+EOF
+
 # Install ProFTPD package (configuration happens after database setup)
 echo "Installing ProFTPD..."
 dnf install -y proftpd proftpd-mysql
@@ -156,6 +192,18 @@ echo "host=127.0.0.1" >> /root/.my.cnf
 echo "user=root" >> /root/.my.cnf
 echo "password=$mysql_password" >> /root/.my.cnf
 
+# Pull PostgreSQL image
+docker pull postgres:latest
+# Generate PostgreSQL root password
+postgres_password=$(tr -dc 'A-Za-z0-9!?&()-+=' </dev/urandom | head -c 18)
+# Create PostgreSQL data directory
+mkdir -p /docker/postgresql
+# Start PostgreSQL
+docker run -d --network client-net --name postgresql --env POSTGRES_PASSWORD="$postgres_password" -v /docker/postgresql:/var/lib/postgresql/data:Z -p 5432:5432 --restart unless-stopped postgres:latest
+# Store PostgreSQL login details in .pgpass format
+echo "127.0.0.1:5432:*:postgres:$postgres_password" > /root/.pgpass
+chmod 600 /root/.pgpass
+
 # Wait for MySQL to be ready
 echo "Waiting for MySQL to be ready..."
 while ! mysql -e "SELECT 1" >/dev/null 2>&1; do
@@ -164,6 +212,14 @@ while ! mysql -e "SELECT 1" >/dev/null 2>&1; do
 done
 echo "✓ MySQL is ready!"
 
+# Wait for PostgreSQL to be ready
+echo "Waiting for PostgreSQL to be ready..."
+while ! docker exec postgresql pg_isready -U postgres >/dev/null 2>&1; do
+    echo "PostgreSQL is not ready yet, waiting 5 seconds..."
+    sleep 5
+done
+echo "✓ PostgreSQL is ready!"
+
 # Initialize database schemas directly with MySQL
 echo "Setting up complete WHP database structure..."
 mysql < ./sql/complete-database-setup.sql
@@ -402,6 +458,7 @@ systemctl is-active proftpd >/dev/null 2>&1 && echo "✓ FTP server is running"
 echo ""
 echo "Checking container status:"
 docker ps | grep mysql >/dev/null 2>&1 && echo "✓ MySQL container is running" || echo "✗ MySQL container is not running"
+docker ps | grep postgresql >/dev/null 2>&1 && echo "✓ PostgreSQL container is running" || echo "✗ PostgreSQL container is not running"
 docker ps | grep haproxy-manager >/dev/null 2>&1 && echo "✓ HAProxy container is running" || echo "✗ HAProxy container is not running"
 docker ps | grep memcache >/dev/null 2>&1 && echo "✓ Memcache container is running" || echo "✗ Memcache container is not running"
 docker ps | grep powerdns >/dev/null 2>&1 && echo "✓ PowerDNS container is running" || echo "✗ PowerDNS container is not running"
@@ -410,6 +467,7 @@ docker ps | grep powerdns >/dev/null 2>&1 && echo "✓ PowerDNS container is run
 echo ""
 echo "Checking database connectivity:"
 mysql -e "SELECT 1" >/dev/null 2>&1 && echo "✓ MySQL connection successful" || echo "✗ MySQL connection failed"
+docker exec postgresql psql -U postgres -c "SELECT 1" >/dev/null 2>&1 && echo "✓ PostgreSQL connection successful" || echo "✗ PostgreSQL connection failed"
 
 # Set up SSH chroot jail for users in /docker/users/
 if ! grep -q 'Match User \*,!root' /etc/ssh/sshd_config; then
@@ -563,10 +621,13 @@ echo "8. Configure backup targets in the WHP control panel under 'Backup Managem
 echo "9. WordPress auto-updates are configured to run every 6 hours (2 AM, 8 AM, 2 PM, 8 PM)"
 echo "10. WordPress security settings include comprehensive options: file editor blocking, XML-RPC protection, version hiding, security headers, and more"
 echo "11. WebSocket terminal server provides full terminal access to containers via the web interface"
+echo "12. PostgreSQL database server is running on port 5432 with root credentials stored in /root/.pgpass"
+echo "13. pgAdmin 4 is available at https://your-server/pgadmin4 for PostgreSQL management"
 echo ""
 echo "Troubleshooting:"
 echo "- Check logs in /var/log/httpd/ for Apache issues"
-echo "- Use 'docker logs mysql' for database issues"
+echo "- Use 'docker logs mysql' for MySQL database issues"
+echo "- Use 'docker logs postgresql' for PostgreSQL database issues"
 echo "- Ensure .user.ini is copied to web directory if authentication fails"
 echo "- Check backup logs in /var/log/whp-backup-*.log"
 echo "- Check WordPress auto-update logs in /var/log/wordpress-auto-update.log"
