@@ -23,6 +23,7 @@ $server_name = $server_settings['server_name'] ?? 'Web Hosting Panel';
 $allowed_pages = [
     'dashboard' => 'Dashboard',
     'database-management' => 'Database Management',
+    'postgresql-management' => 'PostgreSQL Management',
     'email-management' => 'Email Management',
     'backups' => 'Backup Management',
     'wordpress' => 'WordPress Management',
@@ -133,7 +134,10 @@ if (!array_key_exists($page, $allowed_pages)) {
                         <i class="fa fa-database me-3"></i>phpMyAdmin
                     </a>
                     <a href="index.php?page=database-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'database-management' ? 'active' : ''; ?>">
-                        <i class="fa fa-database me-3"></i>Database Management
+                        <i class="fa fa-database me-3"></i>MySQL Management
+                    </a>
+                    <a href="index.php?page=postgresql-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'postgresql-management' ? 'active' : ''; ?>">
+                        <i class="fa fa-database me-3"></i>PostgreSQL Management
                     </a>
                     <a href="index.php?page=email-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'email-management' ? 'active' : ''; ?>">
                         <i class="fa fa-envelope me-3"></i>Email Management
