@@ -200,6 +200,14 @@ class WordPressManager {
             throw new Exception("Failed to install WordPress: " . $result['output']);
         }
         
+        // Install wp-cli-login-command plugin for auto-login functionality
+        $loginPluginCmd = "wp package install aaemnnosttv/wp-cli-login-command";
+        $loginResult = $this->execWpCli($data['container'], $data['user'], $loginPluginCmd, $path);
+        if (!$loginResult['success']) {
+            // Log warning but don't fail the installation
+            error_log("Warning: Failed to install wp-cli-login-command: " . $loginResult['output']);
+        }
+        
         // Save site information to database
         $stmt = $this->db->prepare("
             INSERT INTO wordpress_sites 
@@ -475,6 +483,14 @@ Options -Indexes
         // Create default security settings
         $this->createDefaultSecuritySettings($wpSiteId);
         
+        // Install wp-cli-login-command plugin for auto-login functionality
+        $loginPluginCmd = "wp package install aaemnnosttv/wp-cli-login-command";
+        $loginResult = $this->execWpCli($container, $user, $loginPluginCmd, $sitePath);
+        if (!$loginResult['success']) {
+            // Log warning but don't fail the import
+            error_log("Warning: Failed to install wp-cli-login-command during import: " . $loginResult['output']);
+        }
+        
         // Set backup target if specified
         if (!empty($data['import_backup_target_id'])) {
             $stmt = $this->db->prepare("UPDATE wordpress_sites SET backup_target_id = ? WHERE id = ?");
@@ -697,97 +713,45 @@ Options -Indexes
             throw new Exception("Permission denied: You can only create login tokens for your own WordPress sites");
         }
         
-        // Generate secure random string for filename
-        $randomString = bin2hex(random_bytes(16));
-        $filename = "delete-me-{$randomString}.php";
+        $path = "/home/{$site['user']}/public_html";
         
-        // Use host filesystem path instead of container path
-        $hostPath = "/docker/users/{$site['user']}/{$site['domain']}/public_html";
-        $filePath = "{$hostPath}/{$filename}";
-        
-        // Create the auto-login PHP file content
-        $loginFileContent = '<?php
-/**
- * WHP Auto-Login File
- * This file will delete itself after successful login
- * Generated: ' . date('Y-m-d H:i:s') . '
- * Expires: ' . date('Y-m-d H:i:s', time() + 300) . '
- */
-
-// Check if this file has expired (5 minutes)
-$creationTime = filemtime(__FILE__);
-if (time() - $creationTime > 300) {
-    unlink(__FILE__);
-    wp_die("Login link has expired");
-}
-
-// Load WordPress
-require_once(dirname(__FILE__) . "/wp-load.php");
-
-// Get the admin username from WordPress users
-$admin_users = get_users(array(
-    "role" => "administrator",
-    "number" => 1
-));
-
-if (empty($admin_users)) {
-    unlink(__FILE__);
-    wp_die("No admin user found");
-}
-
-$admin_user = $admin_users[0];
-
-// Log in the user
-wp_set_current_user($admin_user->ID);
-wp_set_auth_cookie($admin_user->ID);
-
-// Delete this file
-unlink(__FILE__);
-
-// Redirect to WordPress admin
-wp_redirect(admin_url());
-exit;
-?>';
-        
-        // Check if the host directory exists
-        if (!is_dir($hostPath)) {
-            throw new Exception("WordPress directory not found: {$hostPath}");
+        // Use the admin username from the database
+        $adminUsername = $site['admin_username'];
+        if (empty($adminUsername)) {
+            throw new Exception("No admin username found for this WordPress site");
         }
         
-        // Write the file directly to the host filesystem
-        if (file_put_contents($filePath, $loginFileContent) === false) {
-            throw new Exception("Failed to create login file");
+        // Create magic login link using wp-cli-login-command plugin
+        $cmd = "wp login create " . escapeshellarg($adminUsername);
+        $result = $this->execWpCli($site['container_name'], $site['user'], $cmd, $path);
+        
+        if (!$result['success']) {
+            throw new Exception("Failed to create login link: " . $result['output']);
         }
         
-        // Set proper file permissions (644) and ownership
-        chmod($filePath, 0644);
+        // Parse the output to extract the login URL
+        $output = $result['output'];
+        $lines = explode("\n", $output);
+        $loginUrl = null;
         
-        // Get the user's UID and GID for proper ownership
-        if (function_exists('posix_getpwnam')) {
-            $userInfo = posix_getpwnam($site['user']);
-            if ($userInfo !== false) {
-                chown($filePath, $userInfo['uid']);
-                chgrp($filePath, $userInfo['gid']);
-            }
-        } else {
-            // Fallback: use shell command to get UID/GID
-            $uid = trim(shell_exec("id -u " . escapeshellarg($site['user']) . " 2>/dev/null"));
-            $gid = trim(shell_exec("id -g " . escapeshellarg($site['user']) . " 2>/dev/null"));
-            
-            if (is_numeric($uid) && is_numeric($gid)) {
-                chown($filePath, (int)$uid);
-                chgrp($filePath, (int)$gid);
+        foreach ($lines as $line) {
+            $line = trim($line);
+            // Look for URLs that start with http
+            if (preg_match('/^https?:\/\//', $line)) {
+                $loginUrl = $line;
+                break;
             }
         }
         
-        // Create login URL
-        $loginUrl = "https://{$site['domain']}/{$filename}";
+        if (!$loginUrl) {
+            throw new Exception("Could not extract login URL from wp-cli output: " . $output);
+        }
         
         return [
             'success' => true,
             'login_url' => $loginUrl,
-            'expires_at' => date('Y-m-d H:i:s', time() + 300),
-            'message' => 'Auto-login link created successfully. Link expires in 5 minutes.'
+            'expires_at' => date('Y-m-d H:i:s', time() + 900), // wp-cli-login-command expires in 15 minutes
+            'message' => 'Magic login link created successfully. Link expires in 15 minutes or after first use.'
         ];
     }
     
